@@ -98,7 +98,10 @@ class DownloadManager:
             return self.client.future_session.executor.submit(self.download_from_url, l)
         else:
             # return true because we don't want to try to download again.
-            return (True, l.link)
+            def return_true(l):
+                return True, l.link
+
+            return self.client.future_session.executor.submit(return_true, l)
 
     def download(self):
         futures = [d for l in self.urls if (d := self._download(l)) is not None]
